/*
We'll use 3 data sets: the 10 percent sample from the Current Population 
Survey (CPS), the 2018 GSS, and the GSS cumulative file. Download all 3 and 
set your working directory.

We'll use the CPS first
*/


clear
cd "/Users/campbellco16/Desktop/Data/CPS/"
use cps2016_10pct

*cleaning up family income
gen fam_inc=ftotval
replace fam_inc=. if ftotval<0 | ftotval==0 
replace fam_inc=. if ftotval>250000

*Slide 7
hist fam_inc, frequency

*Slide 8
hist fam_inc, frequency ///
	title("Histogram of Family Income", color(green) size(large)) ///
	ytitle("Frequency", color(purple) size(medsmall)) ///
	xtitle({it:Family Income}) ///
	graphregion(color(yellow)) ///
	xlab(0(25000)250000, angle(45)) ///
	ylab(0(100)1200, angle(0)) ///
	fcolor(blue) ///
	color(pink) ///
	note("Data: Current Population Survey")

*Slide 12
hist fam_inc, frequency ///
	title("Histogram of Family Income", color(black) size(medlarge)) ///
	ytitle("Frequency", color(black)) ///
	xtitle("Family Income") ///
	graphregion(color(white)) ///
	xlab(0(25000)250000, angle(45)) ///
	ylab(0(100)1200, angle(0)) ///
	fcolor("89 42 138") ///
	color("255 199 2") ///
	note("Data: Current Population Survey")	

*slide 16
hist fam_inc, frequency
*slide 17
hist fam_inc, frequency scheme(lean2)
*slide 18
hist fam_inc, frequency scheme(economist)

/*
the next two schemes were created by people and not part of Stata
In the command window, run ssc install blindschemes (this will let you use the 
plottig scheme
Then, in the command window, run:
net install cleanplots, from("https://tdmize.github.io/data/cleanplots")
(this will let you use the cleanplots scheme
*/
*slide 19
hist fam_inc, frequency scheme(plottig)
*slide 20
hist fam_inc, frequency scheme(cleanplots)

*slide 27
hist fam_inc, scheme(lean2) frequency ///
	xtitle("Household Income")	

*slide 28	
hist fam_inc, scheme(lean2) percent xtitle("Household Income")	   
	
	
gen college=0 if educ>=0 & educ<=110
replace college=1 if educ>=111 & educ<=125	

*slide 29
twoway ///
	(hist fam_inc if college==1, fcolor(none) color(red) freq) ///
	(hist fam_inc if college==0, fcolor(none) color(blue) freq), ///
	legend(order(1 "College Degree" 2 "No College")) ///
	title("Histogram of Family Income by Educational Attainment") ///
	scheme(lean2) xtitle("Family Income")

*slide 31	
twoway ///
	(hist fam_inc if college==1, fcolor(none) color(red) percent) ///
	(hist fam_inc if college==0, fcolor(none) color(blue) percent), ///
	legend(order(1 "College Degree" 2 "No College")) ///
	title("Histogram of Family Income by Educational Attainment") ///
	scheme(lean2) xtitle("Family Income")	
	
gen wages=inctot/(uhrsworkt*52) if inctot>0 & uhrsworkt>0 & uhrsworkt!=999 ///
	& inctot<250000
drop if wages>100	

*slide 34	
twoway ///
	(kdensity wages if college==1, color(red)) ///
	(kdensity wages if college==0, color(blue)), ///
	legend(order(1 "College Degree" 2 "No College")) ///
	title("Kernel Density Plot of Wages by Educational Attainment") ///
	scheme(lean2) xtitle("Wages")	
	
gen ed_cat=0 if educ>=0 & educ<=72
replace ed_cat=1 if educ==73	
replace ed_cat=2 if educ>=80 & educ<=110
replace ed_cat=3 if educ==111
replace ed_cat=4 if educ>=123 & educ<=125
label define ed 0 "<HS" 1 "HS" 2 "Some College" 3 "College" 4 "Adv Degree"
label values ed_cat ed

*slide 36
twoway ///
	(kdensity wages if ed_cat==0, color(red)) ///
	(kdensity wages if ed_cat==1, color(lavender)) ///
	(kdensity wages if ed_cat==2, color(blue)) ///
	(kdensity wages if ed_cat==3, color(green)) ///
	(kdensity wages if ed_cat==4, color(purple)), ///
	legend(order(1 "<HS" 2 "HS" 3 "Some College" 4 "BA" 5 "Adv Degree")) ///
	title("Kernel Density Plot of Wages by Educational Attainment") ///
	scheme(lean2) xtitle("Wages")	

*slide 39	
twoway scatter wages age, scheme(lean2) msize(vsmall) xlab(20(10)80) ///
	title("Scatterplot of Hourly Wages and Age of Worker") ///
	ytitle("Wages")

*slide 40	
twoway scatter wages age, scheme(lean2) msize(vsmall) xlab(20(10)80) ///
	title("Scatterplot of Hourly Wages and Age of Worker") ///
	ytitle("Wages") ///
	jitter(3)

*slide 41	
twoway ///
	(scatter wages age, scheme(lean2) msize(vsmall) xlab(20(10)80) ///
	title("Scatterplot of Hourly Wages and Age of Worker") ///
	ytitle("Wages") ///
	jitter(3))	///
	(lfit wages age, color(red)) 

*slide 43	
twoway ///
	(scatter wages age, scheme(lean2) msize(vsmall) xlab(20(10)80) ///
	title("Scatterplot of Hourly Wages and Age of Worker") ///
	ytitle("Wages") ///
	jitter(3))	///
	(qfit wages age, color(red)) 	
	
*slide 45
twoway (scatter wages age if ed_cat==0, msize(vsmall) msym(oh) mcolor(pink) jitter(3)) || ///
	(scatter wages age if ed_cat==1, msize(vsmall) msym(oh) mcolor(blue) jitter(3)) || ///
	(scatter wages age if ed_cat==2, msize(vsmall) msym(oh) mcolor(green) jitter(3)) || ///
	(scatter wages age if ed_cat==3, msize(vsmall) msym(oh) mcolor(red) jitter(3)) || ///
	(scatter wages age if ed_cat==4, msize(vsmall) msym(oh) mcolor(black) jitter(3)) ||, ///
	title("Scatterplot of Hourly Wages and Age of Worker") ///
	ytitle("Wages") ///
	legend(order(1 "<HS" 2 "HS" 3 "Some College" 4 "College" 5 "Advanced Degree")) ///
	xlab(15(10)85) scheme(cleanplots)
	

*slide 48
graph box wages, over(ed_cat) ///
	box(1, col(gs8)) marker(1, mcol(gs12)) ///
	title("Hourly Wages by Educational Attainment") ///
	ytitle("Hourly Wages") scheme(cleanplots)

*slide 49	
graph hbox wages, over(ed_cat) ylab(0(10)100) ///
	box(1, col(gs8)) marker(1, mcol(gs12)) ///
	title("Hourly Wages by Educational Attainment") ///
	ytitle("Hourly Wages") scheme(cleanplots)
	
gen female=1 if sex==2
replace female=0 if sex==1
label define gender 0 "Men" 1 "Women"
label values female gender

*slide 50	
graph hbox wages, over(ed_cat) over(female)	scheme(cleanplots) ytitle("Wages")

*slide 51
graph hbox wages, over(female) over(ed_cat)	scheme(cleanplots) ytitle("Wages")

*SWITCHING TO THE 2018 GSS
clear
cd "/Users/campbellco16/Desktop/Data/GSS/"
use GSS2018
	
*slide 52	
graph pie, over(hlpjob) scheme(s1color)	///
		title("Where respondents would first turn for help finding a job") 

*slide 53		
graph pie, over(hlpjob) pie(3, explode) scheme(s1color) ///
		title("Where respondents would first turn for help finding a job") 


*slide 54
graph hbar, over(hlpjob, gap(50)) asyvars ylab(0(10)50) ///
	bar(1, col(blue*1.5)) bar(2, col(blue)) bar(3, col(blue*.6)) bar(4, col(gs8)) ///
	bar(5, col(red*.6)) bar(6, col(red)) bar(7, col(red*1.5)) ///
	title("Where respondents would first turn for help finding a job") ///
	ytitle("Percent of Sample")	///
	note("Note: GSS 2018") ///
	scheme(cleanplots)
	
*slide 55	
graph hbar, over(hlpjob, sort(1) gap(50)) asyvars ylab(0(10)50) ///
	bar(1, col(blue*1.5)) bar(2, col(blue)) bar(3, col(blue*.6)) bar(4, col(gs8)) ///
	bar(5, col(red*.6)) bar(6, col(red)) bar(7, col(red*1.5)) ///
	title("Where respondents would first turn for help finding a job") ///
	ytitle("Percent of Sample")	///
	note("Note: GSS 2018") ///
	scheme(cleanplots)

*slide 56	
graph hbar, over(hlpjob, sort(1) descending gap(50)) asyvars ylab(0(10)50) ///
	bar(1, col(blue*1.5)) bar(2, col(blue)) bar(3, col(blue*.6)) bar(4, col(gs8)) ///
	bar(5, col(red*.6)) bar(6, col(red)) bar(7, col(red*1.5)) ///
	title("Where respondents would first turn for help finding a job") ///
	ytitle("Percent of Sample")	///
	note("Note: GSS 2018") ///
	scheme(cleanplots)

*slide 57		
graph hbar, over(hlpjob, sort(1) gap(50)) asyvars ylab(0(10)50 23" ") ///
	bar(1, col(blue*1.5)) bar(2, col(blue)) bar(3, col(blue*.6)) bar(4, col(gs8)) ///
	bar(5, col(red*.6)) bar(6, col(red)) bar(7, col(red*1.5)) ///
	blabel(name) legend(off) ///
	title("Where respondents would first turn for help finding a job") ///
	ytitle("Percent of Sample")	///
	note("Note: GSS 2018")  ///
	scheme(cleanplots)

/*
cibar is another user written program. in the command window run: 
ssc install cibar 
*/

*slide 58
cibar conrinc, over1(degree) over2(sex) bargap(20) ///
	graph(title("Average Income by Gender and Education") ///
	ytitle("Mean Income") ylab(0(20000)100000))

*slide 59	
cibar conrinc, over1(sex) over2(degree) ///
	graph(title("Average Income by Gender and Education") ///
	ytitle("Mean Income") ylab(0(20000)100000))


*SWITCHING TO CUMULATIVE GSS FILE and only opening a small number of variables 
clear
use polviews sex year gunlaw using GSS7218_R1.dta

/*

The first graph looks at average polviews score by year. An easy way to do that
is with the collapse command. When we collapse (mean) polviews, by(year)
Stata calculates the mean polview score for each year and only retains those two
vairables: year and average polview score
*/

*run
collapse (mean) polviews, by(year)
*now browse the data 
br
/*
having the data like this is helpful for making our figures, but before we do 
anything else we have to reload the data, and this is probably not a good option
if you've already done a lot of cleaning 
*/

*Reload the data 
clear
use polviews sex year gunlaw using GSS7218_R1.dta
 
/*
We can solve this problem by using "preserve" before the collapse commands. 
From the Stata help file (slightly edited): 
    preserve deals with the programming problem where the user's data must be 
	changed to achieve the desired result but, when the program concludes, the 
	programmer wishes to undo the damage done to the data.  When preserve is
    issued, the user's data are preserved.  The data in memory remain unchanged.  
	When the program or do-file concludes, the user's data are automatically 
	restored.

We want to highlight all 3 commands at once: preserve, collapse, scatter and run
all the commands together 
(In effect, highlight lines 297 through 304 and execute those commands at the 
same time. The preserve command means that the data are restored after you
execute the commands
*/ 

*slide 61
preserve
collapse (mean) polviews, by(year)
scatter polviews year, ///
	ylab(1(1)7) ///
	xtitle("Year") ///
	ytitle("Average Political Ideology Score") ///
	title("Political Ideology, 1974-2018") ///
	note("Note: 1=Extremely Liberal and 7=Extremely Conservative") ///
	scheme(cleanplots)

*slide 62	
preserve
collapse (mean) polviews, by(year)
scatter polviews year, ///
	ylab(3(.5)5) ///
	xtitle("Year") ///
	ytitle("Average Political Ideology Score") ///
	title("Political Ideology, 1974-2018") ///
	note("Note: 1=Extremely Liberal and 7=Extremely Conservative") ///
	scheme(cleanplots)

*slide 63	
preserve
collapse (mean) polviews, by(year)
scatter polviews year, ///
	ylab(3.8(.2)4.4) ///
	xtitle("Year") ///
	ytitle("Average Political Ideology Score") ///
	title("Political Ideology, 1974-2018") ///
	note("Note: 1=Extremely Liberal and 7=Extremely Conservative")	///
	scheme(cleanplots)
	
*slide 64	
preserve
collapse (mean) polviews, by(year)
twoway line polviews year, ///
	ylab(3(.5)5) ///
	xtitle("Year") ///
	ytitle("Average Political Ideology Score") ///
	title("Political Ideology, 1974-2018") ///
	note("Note: 1=Extremely Liberal and 7=Extremely Conservative") ///
	scheme(cleanplots)
	

	
gen gunfavor=1 if gunlaw==1
replace gunfavor=0 if gunlaw==2	
label define gun 1 "Favor" 0 "Oppose"
label values gunfavor gun

*slide 65
preserve
collapse (mean) gunfavor, by(year sex)
twoway line gunfavor year if sex==1 || ///
	line gunfavor year if sex==2, ///
	ylab(0(.2)1) ///
	xtitle("Year") ///
	ytitle("Proportion Favoring Gun Permits") ///
	title("Support for Gun Permits by Gender, 1974-2018") ///
	legend(order(2 "Women" 1 "Men")) ///
	scheme(cleanplots)
	
*slide 66
preserve
collapse (mean) gunfavor, by(year sex)
twoway scatter gunfavor year if sex==1 || ///
	scatter gunfavor year if sex==2 || ///
	lpoly gunfavor year if sex==1 || ///
	lpoly gunfavor year if sex==2 ||, ///
	ylab(0(.2)1) ///
	xtitle("Year") ///
	ytitle("Proportion Favoring Gun Permits") ///
	title("Support for Gun Permits by Gender, 1974-2018") ///
	legend(order(2 "Women" 1 "Men")) ///
	pcycle(2) ///
	scheme(cleanplots)
*the pcycle command tells stata to go throgh 2 colors and then cycle back so the
*scatter plots and line colors match
	
	
*REOPEN CPS Data	
clear	
cd "/Users/campbellco16/Desktop/Data/CPS/"
use cps2016_10pct

*slide 68 	
reg wages c.age##c.age if age<65
margins, at(age=(15(5)65))
marginsplot, scheme(cleanplots)	title("Predicted Wages by Age") ///
	ytitle("Wages") ///
	xtitle("Age") ///
	ylab(5(5)40) ///
	xlab(15(5)65)

*slide 69
reg wages c.age##c.age##i.female if age<=65
margins, at(age=(15(5)65) female=(0 1))
marginsplot, scheme(cleanplots)	title("Predicted Wages by Age") ///
	ytitle("Wages") ///
	xtitle("Age") ///
	ylab(5(5)40) ///
	xlab(15(5)65)	 ///
	legend(order(2 "Women" 1 "Men")) ///
	recastci(rarea) ///
	ci1opts(fintensity(30)) ///
	ci2opts(fintensity(30))
 
 

*REOPEN CUMULATIVE GSS
clear
cd "/Users/campbellco16/Desktop/Data/GSS/"
use polviews sex year gunlaw degree age spkrac spkath spkmil using GSS7218_R1.dta 

*since i'm setting cleanplots as the scheme here, i don't need to specify that
*in the code for each figure
set scheme cleanplots  
  
gen gunfavor=1 if gunlaw==1
replace gunfavor=0 if gunlaw==2	
label define gun 1 "Favor" 0 "Oppose"
label values gunfavor gun

gen college=1 if degree==3 | degree==4
replace college=0 if degree==0 | degree==1
label define college 0 "No College" 1 "College"
label values college college
 
gen female=1 if sex==2
replace female=0 if sex==1

*slide 70
logit gunfavor i.female##i.year 
margins, at(year=(1972 1973 1974 1975 1976 1977 1980 1982 1984 1985 1987 1988 ///
		1989 1990 1991 1993 1994 1996 1998 2000 2002 2004 2006 2008 2010 ///
		2012 2014 2016 2018) female=(0 1))
marginsplot, ///
	ytitle("Predicted Probability of Favoring Gun Permits") ///
	xtitle("Year") ///
	ylab(0(.2)1, angle(0)) ///
	title("") ///
	legend(order(2 "Women" 1 "Men"))
	
*slide 71	
logit gunfavor c.age##c.age	
margins, at(age=(18(5)80))
marginsplot, ///
	ytitle("Predicted Probability of Favoring Gun Permits") ///
	xtitle("Age") ///
	ylab(.6(.1)1, angle(0)) ///
	title("") ///
	recastci(rarea) ///
	ci1opts(fintensity(30))

	
	
gen racspkok=1 if spkrac==1
replace racspkok=0 if spkrac==2

gen athspkok=1 if spkath==1
replace athspkok=0 if spkath==2

gen milspkok=1 if spkmil==1
replace milspkok=0 if spkmil==2

*slide 72 (and used for figures on slides 73 and 74
logit athspkok i.college##i.year age female	
	margins, at(year=(1976 1977 1980 1982 1984 1985 1987 1988 ///
		1989 1990 1991 1993 1994 1996 1998 2000 2002 2004 2006 2008 2010 ///
		2012 2014 2016) college=(0 1))
	marginsplot, ///
		ytitle("Predicted Probability", size(medsmall))  ///
		xtitle("Year", size(small)) ///
		ylab(0(.2)1, gmin gmax angle(0) labsize(small)) ///
		xlabel(1976 1982 1988 1994 2000 2006 2012 2016, labsize(small) ///
		angle(45)) ///
		plot1opts(lpattern(solid) lcolor(orange) ///
		mcolor(orange) msize(small) msymbol(O)) ///
		plot2opts(lpattern(solid) lcolor(midblue) ///
		mcolor(midblue) msize(small) msymbol(D)) ///		
		recastci(rarea) ///
		ci1opts(color(orange) fintensity(25)) ///
		ci2opts(color(midblue) fintensity(25)) ///
		graphregion(color(white)) ///
		legend(size(vsmall) region(lcolor(white))) ///
		title("Atheist Speech") ///
		saving(class_example2, replace)		

*used for figures on slides 73 and 74		
logit racspkok i.college##i.year age female	
	margins, at(year=(1976 1977 1980 1982 1984 1985 1987 1988 ///
		1989 1990 1991 1993 1994 1996 1998 2000 2002 2004 2006 2008 2010 ///
		2012 2014 2016) college=(0 1))
	marginsplot, ///
		ytitle("Predicted Probability", size(medsmall))  ///
		xtitle("Year", size(small)) ///
		ylab(0(.2)1, gmin gmax angle(0) labsize(small)) ///
		xlabel(1976 1982 1988 1994 2000 2006 2012 2016, labsize(small) ///
		angle(45)) ///
		plot1opts(lpattern(solid) lcolor(orange) ///
		mcolor(orange) msize(small) msymbol(O)) ///
		plot2opts(lpattern(solid) lcolor(midblue) ///
		mcolor(midblue) msize(small) msymbol(D)) ///		
		recastci(rarea) ///
		ci1opts(color(orange) fintensity(25)) ///
		ci2opts(color(midblue) fintensity(25)) ///
		graphregion(color(white)) ///
		legend(size(vsmall) region(lcolor(white))) ///
		title("Racist Speech") ///
		saving(class_example1, replace)		

	
*used for figures on slides 73 and 74
logit milspkok i.college##i.year age female	
	margins, at(year=(1976 1977 1980 1982 1984 1985 1987 1988 ///
		1989 1990 1991 1993 1994 1996 1998 2000 2002 2004 2006 2008 2010 ///
		2012 2014 2016) college=(0 1))
	marginsplot, ///
		ytitle("Predicted Probability", size(medsmall))  ///
		xtitle("Year", size(small)) ///
		ylab(0(.2)1, gmin gmax angle(0) labsize(small)) ///
		xlabel(1976 1982 1988 1994 2000 2006 2012 2016, labsize(small) ///
		angle(45)) ///
		plot1opts(lpattern(solid) lcolor(orange) ///
		mcolor(orange) msize(small) msymbol(O)) ///
		plot2opts(lpattern(solid) lcolor(midblue) ///
		mcolor(midblue) msize(small) msymbol(D)) ///		
		recastci(rarea) ///
		ci1opts(color(orange) fintensity(25)) ///
		ci2opts(color(midblue) fintensity(25)) ///
		graphregion(color(white)) ///
		legend(size(vsmall) region(lcolor(white))) ///
		title("Militarist Speech") ///
		saving(class_example3, replace)		
	

*slide 73		
graph combine class_example1.gph class_example2.gph class_example3.gph, ///
	title("Trends in Acceptance of Public Speeches Made by Different Groups")
graph export combined_class_example.pdf, replace

/*
grc1leg is a user written command that is like graph combine but only includes
one legend (grc1leg=graph combine 1 legend). in the command window, run:
ssc install grc1leg
*/

*slide 74
grc1leg class_example1.gph class_example2.gph class_example3.gph, ///
	title("Trends in Acceptance of Public" "Speeches Made by Different Groups") ///
	row(1)
graph display, ysize(6) xsize(9)
graph export combined_class_example2.pdf, replace
